@@ -4,7 +4,6 @@ lalrpop_mod!(#[allow(clippy::all, dead_code, unused_imports)] pub aidl);
 
 #[cfg(test)]
 mod tests {
-    use crate::diagnostic::DiagnosticKind;
     use crate::rules;
     use anyhow::Result;
 
@@ -85,7 +84,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid item - Unrecognized token `oops_interface`\nExpected one of ANNOTATION, ENUM, IMPORT, INTERFACE or PARCELABLE",
+            message: "Invalid item - Unrecognized token `oops_interface`.\nExpected one of ANNOTATION, ENUM, IMPORT, INTERFACE or PARCELABLE",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -143,12 +142,6 @@ mod tests {
             &mut diagnostics
         );
 
-        // Warning generated because it is recommended to define parcelables in AIDL
-        assert_eq!(diagnostics.len(), 3);
-        assert_eq!(diagnostics[0].kind, DiagnosticKind::Warning);
-        assert_eq!(diagnostics[1].kind, DiagnosticKind::Warning);
-        assert_eq!(diagnostics[2].kind, DiagnosticKind::Warning);
-
         Ok(())
     }
 
@@ -222,7 +215,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid interface element - Unrecognized token `;`\nExpected one of \"(\"",
+            message: "Invalid interface element - Unrecognized token `;`.\nExpected \"(\"",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -230,7 +223,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid interface element - Unrecognized token `;`\nExpected one of \")\", \",\", \".\", \">\" or IDENT",
+            message: "Invalid interface element - Unrecognized token `;`.\nExpected one of \")\", \",\", \".\", \">\" or IDENT",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -245,11 +238,11 @@ mod tests {
     fn test_parcelable() -> Result<()> {
         let input = r#"parcelable Tomato {
             /**
-             * member1 documentation
+             * field1 documentation
              */
-            int member1;
+            int field1;
     
-            String member2; // inline comment
+            String field2; // inline comment
         }"#;
         assert_parser!(input, rules::aidl::ParcelableParser::new());
 
@@ -269,9 +262,9 @@ mod tests {
     #[test]
     fn test_parcelable_with_errors() -> Result<()> {
         let input = r#"parcelable Tomato {
-            int member1;
-            wrongmember3;
-            String member3;
+            int field1;
+            wrongfield3;
+            String field3;
         }"#;
         let mut diagnostics = Vec::new();
         assert_parser!(
@@ -284,7 +277,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid member - Unrecognized token `;`\nExpected one of \",\", \".\", \">\" or IDENT",
+            message: "Invalid field - Unrecognized token `;`.\nExpected one of \",\", \".\", \">\" or IDENT",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -342,7 +335,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid enum element - Unrecognized token `=`\nExpected one of \"{\", BOOLEAN, FLOAT or QUOTED_STRING",
+            message: "Invalid enum element - Unrecognized token `=`.\nExpected one of \"{\", BOOLEAN, FLOAT or QUOTED_STRING",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -350,7 +343,7 @@ mod tests {
           Diagnostic(
             kind: Error,
             range: "...",
-            message: "Invalid enum element - Unrecognized token `0843`\nExpected one of \"}\" or IDENT",
+            message: "Invalid enum element - Unrecognized token `0843`.\nExpected one of \"}\" or IDENT",
             context_message: Some("unrecognized token"),
             hint: None,
             related_infos: [],
@@ -480,35 +473,35 @@ mod tests {
     }
 
     #[test]
-    fn test_member() -> Result<()> {
-        let input = "TypeName memberName ;";
-        assert_parser!(input, rules::aidl::MemberParser::new());
+    fn test_field() -> Result<()> {
+        let input = "TypeName fieldName ;";
+        assert_parser!(input, rules::aidl::FieldParser::new());
         Ok(())
     }
 
     #[test]
-    fn test_member_with_value() -> Result<()> {
-        let input = "TypeName memberName = \"member value\";";
-        assert_parser!(input, rules::aidl::MemberParser::new());
+    fn test_field_with_value() -> Result<()> {
+        let input = "TypeName fieldName = \"field value\";";
+        assert_parser!(input, rules::aidl::FieldParser::new());
 
         Ok(())
     }
 
     #[test]
-    fn test_member_with_javadoc() -> Result<()> {
+    fn test_field_with_javadoc() -> Result<()> {
         let input = r#"/**
-             * Member documentation
+             * Field documentation
              */
-            TypeName memberName;"#;
-        assert_parser!(input, rules::aidl::MemberParser::new());
+            TypeName fieldName;"#;
+        assert_parser!(input, rules::aidl::FieldParser::new());
 
         Ok(())
     }
 
     #[test]
-    fn test_member_with_annotation() -> Result<()> {
-        let input = "@AnnotationName TypeName memberName = \"member value\";";
-        assert_parser!(input, rules::aidl::MemberParser::new());
+    fn test_field_with_annotation() -> Result<()> {
+        let input = "@AnnotationName TypeName fieldName = \"field value\";";
+        assert_parser!(input, rules::aidl::FieldParser::new());
 
         Ok(())
     }
@@ -564,6 +557,38 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_type_string() -> Result<()> {
+        let input = "String";
+        assert_parser!(input, rules::aidl::TypeParser::new());
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_type_char_sequence() -> Result<()> {
+        let input = "CharSequence";
+        assert_parser!(input, rules::aidl::TypeParser::new());
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_type_android_builtin() -> Result<()> {
+        let inputs = [
+            "ParcelableHolder",
+            "IBinder",
+            "FileDescriptor",
+            "ParcelFileDescriptor",
+        ];
+
+        for input in inputs.into_iter() {
+            assert_parser!(input, rules::aidl::TypeParser::new());
+        }
+
+        Ok(())
+    }
+
     #[test]
     fn test_type_custom() -> Result<()> {
         let input = "TypeName";
